@@ -1,5 +1,5 @@
 # pylint: disable-msg=W0622
-# copyright 2002-2012 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2002-2021 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of logilab-constraint.
@@ -17,17 +17,17 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with logilab-constraint. If not, see <http://www.gnu.org/licenses/>.
 
-modname = 'constraint'
-distname = 'logilab-constraint'
+modname = "constraint"
+distname = "logilab-constraint"
 
-numversion = (0, 5, 0)
-version = '.'.join(map(str, numversion))
+numversion = (0, 6, 2)
+version = ".".join(map(str, numversion))
 
-license = 'LGPL'
-copyright = '''Copyright (c) 2002-2010 LOGILAB S.A. (Paris, FRANCE).
-http://www.logilab.fr/ -- mailto:contact@logilab.fr'''
+license = "LGPL"
+copyright = """Copyright (c) 2002-2010 LOGILAB S.A. (Paris, FRANCE).
+http://www.logilab.fr/ -- mailto:contact@logilab.fr"""
 
-short_desc = "constraints satisfaction solver in Python"
+description = "constraints satisfaction solver in Python"
 
 long_desc = """Extensible constraint satisfaction problem solver written in pure
 Python, using constraint propagation algorithms. The
@@ -37,12 +37,19 @@ to variables linked to these domains.
 """
 
 author = "Alexandre Fayolle"
-author_email = "alexandre.fayolle@logilab.fr"
+author_email = "contact@logilab.fr"
 
-web = "http://www.logilab.org/projects/%s" % modname
-ftp = "ftp://ftp.logilab.org/pub/%s/" % modname
+web = "http://www.logilab.org/projects/%s" % distname
 mailinglist = "http://lists.logilab.org/mailman/listinfo/python-logic/"
 
-subpackage_of = 'logilab'
-debian_name = 'constraint'
-debian_maintainer_email = 'afayolle@debian.org'
+subpackage_of = "logilab"
+
+classifiers = [
+    "Topic :: Scientific/Engineering",
+    "Programming Language :: Python",
+    "Programming Language :: Python :: 2",
+    "Programming Language :: Python :: 3",
+]
+
+install_requires = ["setuptools", "logilab-common >= 0.63.2", "six >= 1.4.0"]
+tests_require = []
