@@ -1,4 +1,4 @@
-# copyright 2002-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2002-2021 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of logilab-constraint.
@@ -21,22 +21,24 @@
 from logilab.constraint import fd
 from logilab.constraint.propagation import AbstractConstraint, ConsistencyFailure
 
+
 class ChessDomain(fd.FiniteDomain):
     def __init__(self, size):
-        values = [(i,j) for i in range(size) for j in range(size)]
+        values = [(i, j) for i in range(size) for j in range(size)]
         fd.FiniteDomain.__init__(self, values)
 
     def __repr__(self):
         vals = self.getValues()
         vals.sort()
-        return '<ChessDomain %s>' % str(vals)
+        return "<ChessDomain %s>" % str(vals)
+
 
 class QueensConstraint(AbstractConstraint):
     def __init__(self, variables):
         AbstractConstraint.__init__(self, variables)
 
     def __repr__(self):
-        return '<QueensConstraint %s>' % str(self._variables)
+        return "<QueensConstraint %s>" % str(self._variables)
 
     def narrow(self, domains):
         maybe_entailed = 1
@@ -58,9 +60,11 @@ class QueensConstraint(AbstractConstraint):
                     continue
                 val2_0 = val2[0]
                 val2_1 = val2[1]
-                if val1_0  < val2_0 and \
-                   val1_1 != val2_1 and \
-                   abs(val1_0-val2_0) != abs(val1_1-val2_1):
+                if (
+                    val1_0 < val2_0
+                    and val1_1 != val2_1
+                    and abs(val1_0 - val2_0) != abs(val1_1 - val2_1)
+                ):
                     keep1[val1] = 1
                     keep2[val2] = 1
                 else:
@@ -70,10 +74,8 @@ class QueensConstraint(AbstractConstraint):
             dom1.removeValues([val for val in values1 if val not in keep1])
             dom2.removeValues([val for val in values2 if val not in keep2])
         except ConsistencyFailure:
-            raise ConsistencyFailure('Inconsistency while applying %s' % \
-                                     repr(self))
+            raise ConsistencyFailure("Inconsistency while applying %s" % repr(self))
         except Exception:
-            print self, kwargs
+            print(self)
             raise
         return maybe_entailed
-
