@@ -1,5 +1,5 @@
 #!/usr/bin/env python2.2
-# copyright 2002-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2002-2021 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of logilab-constraint.
@@ -18,58 +18,64 @@
 # with logilab-constraint. If not, see <http://www.gnu.org/licenses/>.
 
 
-from logilab.constraint import *
+from logilab.constraint import fd, Repository, Solver
+
 
 def money(verbose=0):
-    """ SEND
-       +MORE
-      -------
-       MONEY
+    """SEND
+     +MORE
+    -------
+     MONEY
     """
     digits = range(10)
-    variables = list('sendmory')
+    variables = list("sendmory")
     domains = {}
     constraints = []
     for v in variables:
         domains[v] = fd.FiniteDomain(digits)
 
     constraints.append(fd.AllDistinct(variables))
-    constraints.append(fd.NotEquals('m', 0))
-    constraints.append(fd.NotEquals('s', 0))
-    constraints.append(fd.make_expression(('s', 'm', 'o'),
-                                          '(s+m) in (10*m+o,10*m+o-1)'))
-    constraints.append(fd.make_expression(('d', 'e', 'y'),
-                                          '(d+e)%10 == y'))
-    constraints.append(fd.make_expression(('n', 'r', 'e'),
-                                          '(n+r)%10 in (e,e-1)'))
-    constraints.append(fd.make_expression(('o', 'e', 'n'),
-                                          '(o+e)%10 in (n,n-1)'))
-    constraints.append(fd.make_expression(variables,
-                'm*10000+(o-m-s)*1000+(n-o-e)*100+(e-r-n)*10+y-e-d == 0'))
+    constraints.append(fd.NotEquals("m", 0))
+    constraints.append(fd.NotEquals("s", 0))
+    constraints.append(
+        fd.make_expression(("s", "m", "o"), "(s+m) in (10*m+o,10*m+o-1)")
+    )
+    constraints.append(fd.make_expression(("d", "e", "y"), "(d+e)%10 == y"))
+    constraints.append(fd.make_expression(("n", "r", "e"), "(n+r)%10 in (e,e-1)"))
+    constraints.append(fd.make_expression(("o", "e", "n"), "(o+e)%10 in (n,n-1)"))
+    constraints.append(
+        fd.make_expression(
+            variables, "m*10000+(o-m-s)*1000+(n-o-e)*100+(e-r-n)*10+y-e-d == 0"
+        )
+    )
     r = Repository(variables, domains, constraints)
     s = Solver().solve_one(r, verbose)
     return s
 
+
 def display_solution(d):
     for s in d:
-        print '  SEND\t  \t','  %(s)d%(e)d%(n)d%(d)d'%s
-        print '+ MORE\t  \t','+ %(m)d%(o)d%(r)d%(e)d'%s
-        print '------\t-->\t','------'
-        print ' MONEY\t  \t',' %(m)d%(o)d%(n)d%(e)d%(y)d'%s
-        print
+        print("  SEND\t  \t", "  %(s)d%(e)d%(n)d%(d)d" % s)
+        print("+ MORE\t  \t", "+ %(m)d%(o)d%(r)d%(e)d" % s)
+        print("------\t-->\t", "------")
+        print(" MONEY\t  \t", " %(m)d%(o)d%(n)d%(e)d%(y)d" % s)
+        print()
 
-if __name__ == '__main__':
-    import sys, getopt
-    opts, args = getopt.getopt(sys.argv[1:], 'dv')
+
+if __name__ == "__main__":
+    import sys
+    import getopt
+
+    opts, args = getopt.getopt(sys.argv[1:], "dv")
     verbose = 0
     display = 0
-    for o,v in opts:
-        if o == '-v':
+    for o, v in opts:
+        if o == "-v":
             verbose += 1
-        if o == '-d':
+        if o == "-d":
             display = 1
     sol = money(verbose)
     if display:
         display_solution([sol])
     else:
-        print sol
+        print(sol)
